@@ -2,6 +2,7 @@ from pathlib import Path
 from textwrap import dedent
 from typing import Optional
 
+import mps
 import typer
 
 from .cli import main as _main
@@ -58,6 +59,15 @@ def analyze(
         """,
         ),
     ),
+    estimate_reference_frame: bool = typer.Option(
+        True,
+        help=dedent(
+            """
+            If True, estimate the the reference frame,
+            by default True. Note that this will overwrite
+            the argument `reference_frame`""",
+        ),
+    ),
     scale: float = typer.Option(
         1.0,
         help=dedent(
@@ -121,12 +131,63 @@ def analyze(
         """,
         ),
     ),
+    video_disp_step: int = typer.Option(
+        24,
+        "--video-disp-step",
+        help="Steps between vectors in displacement movie",
+    ),
+    video_vel_step: int = typer.Option(
+        24,
+        "--video-vel-step",
+        help="Steps between vectors in velocity movie",
+    ),
+    video_disp_scale: int = typer.Option(
+        4,
+        "--video-disp-scale",
+        help="Scale of vectors in displacement movie",
+    ),
+    video_vel_scale: int = typer.Option(
+        1,
+        "--video-vel-scale",
+        help="Scale of vectors in velocity movie",
+    ),
     verbose: bool = typer.Option(False, "--verbose", "-v", help="More verbose"),
+    start_x: Optional[int] = typer.Option(
+        None,
+        "--start-x",
+        help="Start x of selection.",
+    ),
+    end_x: Optional[int] = typer.Option(
+        None,
+        "--end-x",
+        help="End x of selection.",
+    ),
+    start_y: Optional[int] = typer.Option(
+        None,
+        "--start-y",
+        help="Start y of selection.",
+    ),
+    end_y: Optional[int] = typer.Option(
+        None,
+        "--end-y",
+        help="End y of selection.",
+    ),
+    start_t: Optional[int] = typer.Option(
+        None,
+        "--start-t",
+        help="Start time.",
+    ),
+    end_t: Optional[int] = typer.Option(
+        None,
+        "--end-t",
+        help="End time.",
+    ),
 ):
     _main(
         filename=filename,
         algorithm=algorithm,
         reference_frame=reference_frame,
+        estimate_reference_frame=estimate_reference_frame,
         outdir=outdir,
         scale=scale,
         apply_filter=apply_filter,
@@ -135,6 +196,16 @@ def analyze(
         make_displacement_video=make_displacement_video,
         make_velocity_video=make_velocity_video,
         verbose=verbose,
+        video_disp_scale=video_disp_scale,
+        video_disp_step=video_disp_step,
+        video_vel_scale=video_vel_scale,
+        video_vel_step=video_vel_step,
+        start_x=start_x,
+        end_x=end_x,
+        start_y=start_y,
+        end_y=end_y,
+        start_t=start_t,
+        end_t=end_t,
     )
 
 
@@ -164,5 +235,40 @@ def gui(
     sp.run(["streamlit", "run", gui_path.as_posix(), "--", path.as_posix()])
 
 
+@app.command(help="Print info about the file")
+def info(
+    path: Path = typer.Argument(
+        ...,
+        exists=True,
+        file_okay=True,
+        dir_okay=False,
+        readable=True,
+        resolve_path=True,
+        help=dedent(
+            """
+        Path to file
+        """,
+        ),
+    ),
+):
+    data = mps.MPS(path)
+
+    try:
+        from rich.console import Console
+        from rich.table import Table
+
+        console = Console()
+
+        table = Table("Key", "Value", title=f"Info about {path}")
+        for k, v in data.info.items():
+            table.add_row(k, str(v))
+
+        console.print(table)
+    except ImportError:
+        typer.echo(f"Info about {path}")
+        for k, v in data.info.items():
+            typer.echo(f"{k}: {v}")
+
+
 if __name__ == "__main__":
     raise SystemExit(app())
