@@ -61,11 +61,11 @@ def compute_gradients(displacement: Array, dx=1) -> da.Array:
     dvdys = []
 
     logger.info("Compute interpolant Ux")
-    with ProgressBar(out=utils.LoggerWrapper(logger, "info")):
+    with ProgressBar(out=utils.LoggerWrapper(logger, logging.INFO)):
         Uxs = dask.compute(*Uxs)
 
     logger.info("Compute interpolant Uy")
-    with ProgressBar(out=utils.LoggerWrapper(logger, "info")):
+    with ProgressBar(out=utils.LoggerWrapper(logger, logging.INFO)):
         Uys = dask.compute(*Uys)
 
     for (
@@ -78,16 +78,16 @@ def compute_gradients(displacement: Array, dx=1) -> da.Array:
         dvdys.append(dask.delayed(Uy)(x, y, dy=1).T)
 
     logger.info("Compute dudx")
-    with ProgressBar(out=utils.LoggerWrapper(logger, "info")):
+    with ProgressBar(out=utils.LoggerWrapper(logger, logging.INFO)):
         Dudx = da.stack(*dask.compute(dudxs))
     logger.info("Compute dudy")
-    with ProgressBar(out=utils.LoggerWrapper(logger, "info")):
+    with ProgressBar(out=utils.LoggerWrapper(logger, logging.INFO)):
         Dudy = da.stack(*dask.compute(dudys))
     logger.info("Compute dvdx")
-    with ProgressBar(out=utils.LoggerWrapper(logger, "info")):
+    with ProgressBar(out=utils.LoggerWrapper(logger, logging.INFO)):
         Dvdx = da.stack(*dask.compute(dvdxs))
     logger.info("Compute dvdy")
-    with ProgressBar(out=utils.LoggerWrapper(logger, "info")):
+    with ProgressBar(out=utils.LoggerWrapper(logger, logging.INFO)):
         Dvdy = da.stack(*dask.compute(dvdys))
 
     logger.info("Stack arrays")
@@ -138,14 +138,13 @@ def compute_velocity(u: Array, t: Array, spacing: int = 1) -> da.Array:
     da.Array
         Velocity
     """
-    time_axis = u.shape.index(len(t))
-    assert time_axis == 2, "Time axis should be the third axis"
+    assert u.shape[2] == len(t), "Time axis should be the third axis"
     assert u.shape[-1] == 2, "Final axis should be ux and uy"
     assert spacing > 0, "Spacing must be a positive integer"
 
     if spacing == 1:
         dt = da.diff(t)
-        du = da.diff(u, axis=time_axis)
+        du = da.diff(u, axis=2)
     else:
         dt = t[spacing:] - t[:-spacing]
         du = u[:, :, spacing:, :] - u[:, :, :-spacing, :]
